@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
-import csv
+import csv, numbers
 try:
     from itertools import izip
 except ImportError:
     izip = zip
 
 #http://semver.org/
-VERSION = (0, 11, 0)
+VERSION = (0, 11, 1)
 __version__ = ".".join(map(str,VERSION))
 
 pass_throughs = [
@@ -40,7 +40,7 @@ def _stringify(s, encoding, errors):
         return ''
     if isinstance(s, unicode):
         return s.encode(encoding, errors)
-    elif isinstance(s, (int , float)):
+    elif isinstance(s, numbers.Number):
         pass #let csv.QUOTE_NONNUMERIC do its thing.
     elif not isinstance(s, str):
         s=str(s)
@@ -154,7 +154,8 @@ class DictWriter(csv.DictWriter):
         self.encoding_errors = errors
 
     def writeheader(self):
-        header = dict(zip(self.fieldnames, self.fieldnames))
+        fieldnames = _stringify_list(self.fieldnames, self.encoding, self.encoding_errors)
+        header = dict(zip(fieldnames, fieldnames))
         self.writerow(header)
 
 class DictReader(csv.DictReader):
